import unittest
from ybc_bot import *


class MyTestCase(unittest.TestCase):
    def test_listen_ParameterTypeError(self):
        with self.assertRaisesRegex(ParameterTypeError, "^参数类型错误 : 调用listen方法时，'filename'参数类型错误。$"):
            listen(1)

    def test_listen_ParameterValueError(self):
        with self.assertRaisesRegex(ParameterValueError, "^参数数值错误 : 调用listen方法时，'filename'参数不在允许范围内。$"):
            listen('')

    def test_analysis_ParameterTypeError(self):
        with self.assertRaisesRegex(ParameterTypeError, "^参数类型错误 : 调用analysis方法时，'filename'参数类型错误。$"):
            answer_voice(1)

    def test_analysis_ParameterValueError(self):
        with self.assertRaisesRegex(ParameterValueError, "^参数数值错误 : 调用analysis方法时，'filename'参数不在允许范围内。$"):
            answer_voice('')

    def test_chat(self):
        self.assertIsNotNone(chat('你好'))

    def test_chat_ParameterTypeError(self):
        with self.assertRaisesRegex(ParameterTypeError, "^参数类型错误 : 调用chat方法时，'text'参数类型错误。$"):
            chat(1)

    def test_chat_ParameterValueError(self):
        with self.assertRaisesRegex(ParameterValueError, "^参数数值错误 : 调用chat方法时，'text'参数不在允许范围内。$"):
            chat('')


if __name__ == '__main__':
    unittest.main()



import requests
import ybc_config
from ybc_exception import *
import sys
import json

__PREFIX = ybc_config.config['prefix']
__IDIOM_URL = __PREFIX + ybc_config.uri + '/bot'


def chat(text=''):
    error_msg = "'text'"
    if not isinstance(text, str):
        raise ParameterTypeError(function_name=sys._getframe().f_code.co_name, error_msg=error_msg)
    if text == '':
        raise ParameterValueError(function_name=sys._getframe().f_code.co_name, error_msg=error_msg)
    try:
        data = {
            'text': text
        }
        url = __IDIOM_URL
        for i in range(3):
            r = requests.post(url, data=data)
            if r.status_code == 200:
                res = r.json()
                if res['results']:
                    if 'text' in res['results'][0]['values'].keys():
                        res = res['results'][0]['values']['text']
                    else:
                        res = res['results'][1]['values']['text'] + " " + res['results'][0]['values']['url']
                    return res

        raise ConnectionError('获取机器人对话失败', r._content)

    except Exception as e:
        raise InternalError(e, 'ybc_bot')


def main():
    print(chat('北京的pm2.5'))


if __name__ == '__main__':
    main()



#!/usr/bin/env python

from distutils.core import setup

setup(name='ybc_bot',
      version='1.0.15',
      description='Smart bot.',
      long_description='Smart bot little ape.',
      author='hurs',
      author_email='hurs@fenbi.com',
      keywords=['python', 'smart bot', 'bot'],
      url='http://pip.zhenguanyu.com/',
      packages=['ybc_bot'],
      package_data={'ybc_bot': ['*.py']},
      license='MIT',
      install_requires=[
            'requests',
            'ybc_config',
            'ybc_exception',
            'webrtcvad',
            'pyaudio',
            'ybc_speech',
            'ybc_browser',
            'ybc_tuya',
            'pypinyin']
      )
